<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	
	<!--
	 Description : feuille de style pour la gnration d'une page standard XHTML (XML vers HTML)
	 Auteur : David ROUSSE, d.rousse@wanadoo.fr
	 Date derniere modification : 01/01/2004
	-->
	
	<!-- Dclaration des import -->
	<xsl:import href="document_base.xsl"/>
	
	<!-- Dclaration du format de sortie -->
	<xsl:output indent="yes" doctype-public="-//W3C//DTD HTML 4.0 Transitional//EN" encoding="ISO-8859-1" method="html" media-type="text/html" />
	
	<!-- ====================================================================== -->
	<!-- document section -->
	<!-- ====================================================================== -->
	<xsl:template match="document">
		<xsl:apply-templates/>
		<xsl:if test="header/authors">
			<div align="right" id="authors">
				<xsl:for-each select="header/authors/person">
					<xsl:choose>
						<xsl:when test="position()=1">par&#160;</xsl:when>
						<xsl:otherwise>,&#160;</xsl:otherwise>
					</xsl:choose>
					<!-- Ajout lien avec adresse mail DRO le 1/1/04 -->
					<a href="mailto:{@email}">
						<xsl:value-of select="@name"/>
					</a>
				</xsl:for-each>
			</div>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="body">
		<xsl:apply-templates/>
	</xsl:template>
	
	<!-- ====================================================================== -->
	<!-- header section -->
	<!-- ====================================================================== -->
	<xsl:template match="header">
		<!-- ignore on general document -->
	</xsl:template>
	
	<!-- ====================================================================== -->
	<!-- body section -->
	<!-- ====================================================================== -->
	<xsl:template match="section">
		<xsl:variable name="level" select="count(ancestor::section)+1"/>
		<xsl:choose>
			<xsl:when test="$level=1">
				<div class="h3">
					<h3>
						<xsl:value-of select="title"/>
					</h3>
				</div>
				<xsl:apply-templates/>
			</xsl:when>
			<xsl:when test="$level=2">
				<div class="h4">
					<h4>
						<xsl:value-of select="title"/>
					</h4>
				</div>
				<xsl:apply-templates/>
			</xsl:when>
			<xsl:when test="$level=3">
				<div class="h2">
					<h2>
						<xsl:value-of select="title"/>
					</h2>
				</div>
				<xsl:apply-templates/>
			</xsl:when>
			<xsl:otherwise>
				<div class="h5">
					<h5>
						<xsl:value-of select="title"/>
					</h5>
				</div>
				<xsl:apply-templates/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="title">
	</xsl:template>
	
	<!-- ====================================================================== -->
	<!-- footer section -->
	<!-- ====================================================================== -->
	<xsl:template match="footer">
		<!-- ignore on general documents -->
	</xsl:template>
	
	<!-- ====================================================================== -->
	<!-- paragraph section -->
	<!-- ====================================================================== -->
	<xsl:template match="p">
		<xsl:apply-imports/>
	</xsl:template>
	
	<xsl:template match="note">
		<xsl:apply-imports/>
	</xsl:template>
	
	<xsl:template match="source">
		<xsl:apply-imports/>
	</xsl:template>
	
	<xsl:template match="//source/font">
		<font color="{@color}">
			<xsl:apply-templates/>
		</font>
	</xsl:template>
	
	<xsl:template match="fixme">
		<xsl:apply-imports/>
	</xsl:template>
	
	<!-- ====================================================================== -->
	<!-- list section -->
	<!-- ====================================================================== -->
	<xsl:template match="ul|ol|dl">
		<xsl:apply-imports/>
	</xsl:template>
	
	<xsl:template match="li">
		<xsl:apply-imports/>
	</xsl:template>
	
	<xsl:template match="sl">
		<xsl:apply-imports/>
	</xsl:template>
	
	<xsl:template match="dt">
		<xsl:apply-imports/>
	</xsl:template>
	
	<!-- ====================================================================== -->
	<!-- table section -->
	<!-- ====================================================================== -->
	<xsl:template match="table">
		<xsl:apply-imports/>
	</xsl:template>
	
	<xsl:template match="tr">
		<xsl:variable name="index">
			<xsl:number/>
		</xsl:variable>
		<tr>
			<xsl:choose>
				<xsl:when test="($index mod 2) = 0">
					<xsl:attribute name="class">a</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="class">b</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:apply-templates/>
		</tr>
	</xsl:template>
	
	<xsl:template match="th">
		<xsl:apply-imports/>
	</xsl:template>
	
	<xsl:template match="td">
		<xsl:apply-imports/>
	</xsl:template>
	
	<xsl:template match="tn">
		<xsl:apply-imports/>
	</xsl:template>
	
	<xsl:template match="caption">
		<!-- ignore since already used -->
	</xsl:template>
	
	<!-- ====================================================================== -->
	<!-- markup section -->
	<!-- ====================================================================== -->
	<xsl:template match="strong">
		<xsl:apply-imports/>
	</xsl:template>
	
	<xsl:template match="em">
		<xsl:apply-imports/>
	</xsl:template>
	
	<xsl:template match="code">
		<xsl:apply-imports/>
	</xsl:template>
	
	<!-- ====================================================================== -->
	<!-- images section -->
	<!-- ====================================================================== -->
	<xsl:template match="figure">
		<xsl:apply-imports/>
	</xsl:template>
	
	<xsl:template match="img">
		<xsl:apply-imports/>
	</xsl:template>
	
	<xsl:template match="icon">
		<xsl:apply-imports/>
	</xsl:template>
	
	<!-- ====================================================================== -->
	<!-- links section -->
	<!-- ====================================================================== -->
	<xsl:template match="link">
		<xsl:apply-imports/>
	</xsl:template>
	
	<xsl:template match="connect">
		<xsl:apply-imports/>
	</xsl:template>
	
	<xsl:template match="jump">
		<xsl:apply-imports/>
	</xsl:template>
	
	<xsl:template match="fork">
		<xsl:apply-imports/>
	</xsl:template>
	
	<xsl:template match="anchor">
		<xsl:apply-imports/>
	</xsl:template>
	
	<!-- ====================================================================== -->
	<!-- specials section -->
	<!-- ====================================================================== -->
	<xsl:template match="br">
		<xsl:apply-imports/>
	</xsl:template>
	
</xsl:stylesheet>
