<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	
	<!--
	 Description : feuille de style de base (issue du projet Apache Forrest) pour la gnration d'une page standard XHTML (XML vers HTML)
	 Auteur : David ROUSSE, d.rousse@wanadoo.fr
	 Date derniere modification : 01/01/2004
	-->
	
	<!-- Dclaration du format de sortie -->
	<xsl:output indent="yes" doctype-public="-//W3C//DTD HTML 4.0 Transitional//EN" encoding="ISO-8859-1" method="html" media-type="text/html" />
	
	<xsl:template match="@id">
		<xsl:if test="normalize-space(.)!=''">
			<a name="{.}"/>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="note | warning | fixme">
		<xsl:apply-templates select="@id"/>
		<div class="frame {local-name()}">
			<div class="label">
				<xsl:choose>
					<xsl:when test="local-name() = 'note'">Note</xsl:when>
					<xsl:when test="local-name() = 'warning'">Warning</xsl:when>
					<xsl:otherwise>Fixme (
               <xsl:value-of select="@author"/>

               )</xsl:otherwise>
				</xsl:choose>
			</div>
			<div class="content">
				<xsl:apply-templates/>
			</div>
		</div>
	</xsl:template>
	
	<xsl:template match="link">
		<xsl:apply-templates select="@id"/>
		<xsl:choose>
			<xsl:when test="starts-with(@href, 'mailto:') and contains(@href, '@')">
				<xsl:variable name="mailto-1" select="substring-before(@href,'@')"/>
				<xsl:variable name="mailto-2" select="substring-after(@href,'@')"/>
				<a href="{$mailto-1}@{$mailto-2}">
					<xsl:apply-templates/>
				</a>
			</xsl:when>
			<!-- Ajout DRO le 19/11/2003 -->
			<xsl:when test="starts-with(@href, 'http://')">
				<a target="_blank" href="{@href}">
					<xsl:apply-templates/>
				</a>
			</xsl:when>
			<!-- Fin ajout DRO -->
			<xsl:otherwise>
				<a href="{@href}">
					<xsl:apply-templates/>
				</a>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="jump">
		<xsl:apply-templates select="@id"/>
		<a href="{@href}" target="_top">
			<xsl:apply-templates/>
		</a>
	</xsl:template>
	
	<xsl:template match="fork">
		<xsl:apply-templates select="@id"/>
		<a href="{@href}" target="_blank">
			<xsl:apply-templates/>
		</a>
	</xsl:template>
	
	<xsl:template match="p[@xml:space='preserve']">
		<xsl:apply-templates select="@id"/>
		<div class="pre">
			<xsl:apply-templates/>
		</div>
	</xsl:template>
	
	<xsl:template match="source">
		<xsl:apply-templates select="@id"/>
		<pre class="code">
			<xsl:apply-templates/>
		</pre>
	</xsl:template>
	
	<xsl:template match="anchor">
		<a name="{@id}"/>
	</xsl:template>
	
	<xsl:template match="icon">
		<xsl:apply-templates select="@id"/>
		<img src="{@src}" alt="{@alt}">
			<xsl:if test="@height">
				<xsl:attribute name="height"><xsl:value-of select="@height"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@width">
				<xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
			</xsl:if>
		</img>
	</xsl:template>
	
	<xsl:template match="code">
		<xsl:apply-templates select="@id"/>
		<span class="codefrag">
			<xsl:value-of select="."/>
		</span>
	</xsl:template>
	
	<xsl:template match="figure">
		<xsl:apply-templates select="@id"/>
		<div align="center">
			<img src="{@src}" alt="{@alt}" class="figure">
				<xsl:if test="@height">
					<xsl:attribute name="height"><xsl:value-of select="@height"/></xsl:attribute>
				</xsl:if>
				<xsl:if test="@width">
					<xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
				</xsl:if>
			</img>
		</div>
	</xsl:template>
	
	<xsl:template match="table">
		<xsl:apply-templates select="@id"/>
		<table cellpadding="4" cellspacing="1" class="ForrestTable">
			<xsl:if test="@cellspacing">
				<xsl:attribute name="cellspacing"><xsl:value-of select="@cellspacing"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@cellpadding">
				<xsl:attribute name="cellpadding"><xsl:value-of select="@cellpadding"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@border">
				<xsl:attribute name="border"><xsl:value-of select="@border"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@class">
				<xsl:attribute name="class"><xsl:value-of select="@class"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@bgcolor">
				<xsl:attribute name="bgcolor"><xsl:value-of select="@bgcolor"/></xsl:attribute>
			</xsl:if>
			<!-- Modification par DRO le 16/08/2003 -->
			<xsl:if test="@width">
				<xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute>
			</xsl:if>
			<!-- Fin modification par DRO -->
			<xsl:apply-templates/>
		</table>
	</xsl:template>
	
	<xsl:template match="acronym/@title">
		<xsl:attribute name="title"><xsl:value-of select="normalize-space(.)"/></xsl:attribute>
	</xsl:template>
	
	<xsl:template name="toclink">
		<a>
			<xsl:attribute name="href"><xsl:text>#</xsl:text><xsl:if test="@id"><xsl:value-of select="@id"/></xsl:if></xsl:attribute>
			<xsl:value-of select="title"/>
		</a>
	</xsl:template>
	
	<xsl:template match="node()|@*" priority="-1">
		<xsl:copy>
			<xsl:apply-templates select="@*"/>
			<xsl:apply-templates/>
		</xsl:copy>
	</xsl:template>

</xsl:stylesheet>
